@@ -26,7 +26,7 @@ KEY_TABLE = {
     'numbersign': '#',
     'dollar': '$',
     'percent': '%',
-    'ampersand': '^',
+    'ampersand': '&',
     'asterisk': '*',
     'parenleft': '(',
     'parenright': ')',
@@ -35,8 +35,8 @@ KEY_TABLE = {
     'minus': '-',
     'bracketleft': '[',
     'bracketright': ']',
-    'braceleft': '[',
-    'braceright': ']',
+    'braceleft': '{',
+    'braceright': '}',
     'dead_diaeresis': '"',
     'dead_acute': "'",
     'less': "<",
